#!/bin/ksh
###########################################################################
#
# Licensed Materials - Property of IBM
# 5724-T05
#
# (C) Copyright IBM Corp. 2003,2008. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
###########################################################################
#> This script will install Lucent UMTS components
#> patch: 6.0.9.2.1
#> Usage: install.sh {-help | -install | -uninstall}
#

# Required values defined
export PATCH_VER=6.0.9.2.1
export START_DIR=`pwd`
export SOURCE_DIR=${FLEXPM_HOME}/patches/${PATCH_VER}
export BACKUP_DIR=$START_DIR/Backup

# **************************************************************
# The following are 'standard' routines to be used before
# attempting to apply and upgrade/patch
# **************************************************************
# ***
# Check the essential environment settings have been defined before attempting
# any installation procedures.
# ***
function CheckEnvironment {

  # Check FLEXPM_HOME is defined 
  if [[ -z ${FLEXPM_HOME} || ! -d ${FLEXPM_HOME} ]]; then
    echo ""
    echo "+> Env variable FLEXPM_HOME must be set to appropriate dir before installation."
    echo ""
    exit 1;
  fi
  # Check PROSPECT_HOME is defined 
  if [[ -z ${PROSPECT_HOME} || ! -d ${PROSPECT_HOME} ]]; then
    echo ""
    echo "+> Env variable FLEXPM_HOME must be set to appropriate dir before installation."
    echo ""
    exit 1;
  fi
  # Check LuUMTS_CS_HOME is defined 
  if [[ -z ${LuUMTS_CS_HOME} || ! -d ${LuUMTS_CS_HOME} ]]; then
    echo ""
    echo "+> Env variable LuUMTS_CS_HOME must be set to appropriate dir before installation."
    echo ""
    exit 1;
  fi
  # Check that the DB_CONNECT string is defined.
  if [[ -z ${DB_CONNECT} ]]; then
    echo ""
    echo "+> Env variable DB_CONNECT must be set to approriate database connection values."
    echo ""
    exit 1;
  fi
  # Check VENDOR pre-requisite
  PRE_REQ=`show_installed | grep 'LuUMTS_CS rev 6.0.9.2.0'`
  if [[ -z ${PRE_REQ} ]]; then
    echo ""
    echo "+> Lucent UMTS_CS (LuUMTS_CS) 6.0.9.2.0 must be installed before applying this patch."
    echo ""
    exit 1;
  fi
}

# **************************************************************
# End of routines and start of main patch
# **************************************************************

# Check that the passed parameters are correct
if [[ $# -ne 1 ]]; then
  echo
  echo "Invalid number of arguments"
  echo
  echo "Usage : $0 {-help | -install | -uninstall}"
  echo
  exit;
fi

case $1 in
  -install)
    echo ""
    date +"+ Patch install started at %T, %D ..."
    echo ""

    # Check env settings
    echo ""
    echo "+ Checking environment ..."
    CheckEnvironment
    echo "+ Environment appears to be OK ..."
    echo ""

    # Install updated components
    if [ ! -d $BACKUP_DIR ]
    then
      mkdir $BACKUP_DIR
    fi
    
    echo
    echo "Registering Lucent ${PATCH_VER} ..."
    chmod +x $FLEXPM_HOME/pm/adm/register
    register start ${SOURCE_DIR}/LuUMTS_CS.build
    echo


    ########################################################
    echo "+ Installing updated files..."
    ########################################################

    cd $SOURCE_DIR/sources

    for new_dir in `find . -type d|cut -c3-`
    do
      if [[ -d ${FLEXPM_BASE}/$new_dir ]]; then
        echo "dir ok: $new_dir"
      else
        echo "create: $new_dir"
        mkdir -p ${FLEXPM_BASE}/$new_dir
      fi
    done

    touch ${BACKUP_DIR}/backup_sources.tar

    cd $SOURCE_DIR/sources

    for new_file in `find . -type f|cut -c3-`
    do
      cd ${FLEXPM_BASE}
      if [[ -f $new_file ]];
      then
        echo "backup: ${FLEXPM_BASE}/$new_file"
        gtar -uf ${BACKUP_DIR}/backup_sources.tar $new_file
        chmod +w $new_file
      fi
      echo "update: ${FLEXPM_BASE}/$new_file"
      cp -p ${SOURCE_DIR}/sources/$new_file $new_file
    done

    echo
    echo "Updating CallServer find instance package..."
    echo "@${LuUMTS_CS_HOME}/vendor/Lucent/UMTS_CS/Network/wm_cs_sm_find_instance_pkgb.sql" | sqlplus -s $DB_CONNECT

    echo
    echo "Completing registration ..."
    register complete ${SOURCE_DIR}/LuUMTS_CS.build

    cd ${START_DIR}

    echo
    date +"Patch is completed at %T, %D ....."
    break
    ;;
  -uninstall)
    echo ""
    echo "+ Attempting to restore backup files ..."

    cd ${FLEXPM_BASE}

    if [[ -f ${BACKUP_DIR}/backup_sources.tar ]];
    then
      echo "+ Found backup files... restoring ..."
      for file in `gtar -tf ${BACKUP_DIR}/backup_sources.tar`
      do
        if [ -f $file ]
        then
          chmod +w $file
        fi
      done

      gtar -xf ${BACKUP_DIR}/backup_sources.tar

      # Undo the update to CallServer find instance
      echo
      echo "@${LuUMTS_CS_HOME}/vendor/Lucent/UMTS_CS/Network/wm_cs_sm_find_instance_pkgb.sql" | sqlplus -s $DB_CONNECT

      #Remove the component registration for this patch
      COMP_REG=`show_installed | grep '6.0.9.2.1'`
      if [[ ! -z ${COMP_REG} ]]; then
        sq1="select component_version_id from component_version where revision = '6.0.9.2.1' and component_id in (select component_id from component where component_name = 'LuUMTS_CS')"
        sq2="delete component_history where component_version_id in ( $sq1 )"
        sq3="delete component_installed where component_version_id in ( $sq1 )"
        sq4="delete component_version where component_version_id in ( $sq1 )"
sqlplus -s /nolog <<EOF
connect $DBUSER/$DBPASSWD@$DBSID
${sq2};
${sq3};
${sq4};
exit;
EOF

      fi
    else
      echo
      echo "+ Backup files not found... exiting..."
      exit;
    fi
    cd ${START_DIR}
 
    echo
    date +"Patch uninstall is completed at %T, %D ....."
    break
    ;;
  -help)
    echo
    echo "Usage : $0 {-help | -install | -uninstall}"
    echo
    echo "-help      : Display this help text"
    echo "-install   : Install the patch"
    echo "-uninstall : Uninstall the patch"
    echo
    break
    ;;
  *)
    echo
    echo "Invalid argument supplied"
    echo
    echo "Usage : $0 {-help | -install | -uninstall}"
    echo
    break
    ;;
esac

